@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -292,7 +292,7 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
         def __hash__(self):
             return hash("CreateDocumentLink")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -316,7 +316,6 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
                 request (~.document_link_service.CreateDocumentLinkRequest):
                     The request object. Request message for
                 DocumentLinkService.CreateDocumentLink.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -393,7 +392,7 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
         def __hash__(self):
             return hash("DeleteDocumentLink")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -417,7 +416,6 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
                 request (~.document_link_service.DeleteDocumentLinkRequest):
                     The request object. Request message for
                 DocumentLinkService.DeleteDocumentLink.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -480,7 +478,7 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
         def __hash__(self):
             return hash("ListLinkedSources")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -504,7 +502,6 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
                 request (~.document_link_service.ListLinkedSourcesRequest):
                     The request object. Response message for
                 DocumentLinkService.ListLinkedSources.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -581,7 +578,7 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
         def __hash__(self):
             return hash("ListLinkedTargets")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -605,7 +602,6 @@ class DocumentLinkServiceRestTransport(DocumentLinkServiceTransport):
                 request (~.document_link_service.ListLinkedTargetsRequest):
                     The request object. Request message for
                 DocumentLinkService.ListLinkedTargets.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
