@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -327,7 +327,7 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
         def __hash__(self):
             return hash("CreateDocumentSchema")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -351,7 +351,6 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
                 request (~.document_schema_service.CreateDocumentSchemaRequest):
                     The request object. Request message for
                 DocumentSchemaService.CreateDocumentSchema.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -428,7 +427,7 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
         def __hash__(self):
             return hash("DeleteDocumentSchema")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -452,7 +451,6 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
                 request (~.document_schema_service.DeleteDocumentSchemaRequest):
                     The request object. Request message for
                 DocumentSchemaService.DeleteDocumentSchema.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -506,7 +504,7 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
         def __hash__(self):
             return hash("GetDocumentSchema")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -530,7 +528,6 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
                 request (~.document_schema_service.GetDocumentSchemaRequest):
                     The request object. Request message for
                 DocumentSchemaService.GetDocumentSchema.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -598,7 +595,7 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
         def __hash__(self):
             return hash("ListDocumentSchemas")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -622,7 +619,6 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
                 request (~.document_schema_service.ListDocumentSchemasRequest):
                     The request object. Request message for
                 DocumentSchemaService.ListDocumentSchemas.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -690,7 +686,7 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
         def __hash__(self):
             return hash("UpdateDocumentSchema")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -714,7 +710,6 @@ class DocumentSchemaServiceRestTransport(DocumentSchemaServiceTransport):
                 request (~.document_schema_service.UpdateDocumentSchemaRequest):
                     The request object. Request message for
                 DocumentSchemaService.UpdateDocumentSchema.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
