@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -387,7 +387,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("CreateDocument")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -411,7 +411,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.CreateDocumentRequest):
                     The request object. Request message for
                 DocumentService.CreateDocument.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -486,7 +485,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("DeleteDocument")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -510,7 +509,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.DeleteDocumentRequest):
                     The request object. Request message for
                 DocumentService.DeleteDocument.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -576,7 +574,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("FetchAcl")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -600,7 +598,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.FetchAclRequest):
                     The request object. Request message for
                 DocumentService.FetchAcl
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -680,7 +677,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("GetDocument")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -704,7 +701,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.GetDocumentRequest):
                     The request object. Request message for
                 DocumentService.GetDocument.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -784,7 +780,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("SearchDocuments")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -808,7 +804,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.SearchDocumentsRequest):
                     The request object. Request message for
                 DocumentService.SearchDocuments.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -885,7 +880,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("SetAcl")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -909,7 +904,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.SetAclRequest):
                     The request object. Request message for
                 DocumentService.SetAcl.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -989,7 +983,7 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
         def __hash__(self):
             return hash("UpdateDocument")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1013,7 +1007,6 @@ class DocumentServiceRestTransport(DocumentServiceTransport):
                 request (~.document_service_request.UpdateDocumentRequest):
                     The request object. Request message for
                 DocumentService.UpdateDocument.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
