@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -311,7 +311,7 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
         def __hash__(self):
             return hash("CreateRuleSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -335,7 +335,6 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
                 request (~.ruleset_service_request.CreateRuleSetRequest):
                     The request object. Request message for
                 RuleSetService.CreateRuleSet.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -410,7 +409,7 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
         def __hash__(self):
             return hash("DeleteRuleSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -434,7 +433,6 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
                 request (~.ruleset_service_request.DeleteRuleSetRequest):
                     The request object. Request message for
                 RuleSetService.DeleteRuleSet.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -486,7 +484,7 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
         def __hash__(self):
             return hash("GetRuleSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -510,7 +508,6 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
                 request (~.ruleset_service_request.GetRuleSetRequest):
                     The request object. Request message for
                 RuleSetService.GetRuleSet.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -576,7 +573,7 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
         def __hash__(self):
             return hash("ListRuleSets")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -600,7 +597,6 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
                 request (~.ruleset_service_request.ListRuleSetsRequest):
                     The request object. Request message for
                 RuleSetService.ListRuleSets.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -666,7 +662,7 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
         def __hash__(self):
             return hash("UpdateRuleSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -690,7 +686,6 @@ class RuleSetServiceRestTransport(RuleSetServiceTransport):
                 request (~.ruleset_service_request.UpdateRuleSetRequest):
                     The request object. Request message for
                 RuleSetService.UpdateRuleSet.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
