@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -326,7 +326,7 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
         def __hash__(self):
             return hash("CreateSynonymSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -350,7 +350,6 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
                 request (~.synonymset_service_request.CreateSynonymSetRequest):
                     The request object. Request message for
                 SynonymSetService.CreateSynonymSet.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -433,7 +432,7 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
         def __hash__(self):
             return hash("DeleteSynonymSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -457,7 +456,6 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
                 request (~.synonymset_service_request.DeleteSynonymSetRequest):
                     The request object. Request message for
                 SynonymSetService.DeleteSynonymSet.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -511,7 +509,7 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
         def __hash__(self):
             return hash("GetSynonymSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -536,7 +534,6 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
                     The request object. Request message for
                 SynonymSetService.GetSynonymSet. Will
                 return synonymSet for a certain context.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -608,7 +605,7 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
         def __hash__(self):
             return hash("ListSynonymSets")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -634,7 +631,6 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
                 SynonymSetService.ListSynonymSets. Will
                 return all synonymSets belonging to the
                 customer project.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -702,7 +698,7 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
         def __hash__(self):
             return hash("UpdateSynonymSet")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -729,7 +725,6 @@ class SynonymSetServiceRestTransport(SynonymSetServiceTransport):
                 Removes the SynonymSet for the specified
                 context and replaces it with the
                 SynonymSet in this request.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
