@@ -13,9 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
-import google.cloud.documentai_v1.types
+from google.cloud.documentai_v1.types import document as gcd_document
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.type import datetime_pb2  # type: ignore
 import proto  # type: ignore
@@ -181,11 +183,11 @@ class Document(proto.Message):
         number=15,
         oneof="structured_content",
     )
-    cloud_ai_document: google.cloud.documentai_v1.types.Document = proto.Field(
+    cloud_ai_document: gcd_document.Document = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="structured_content",
-        message=google.cloud.documentai_v1.types.Document,
+        message=gcd_document.Document,
     )
     structured_content_uri: str = proto.Field(
         proto.STRING,
